---
name: Feature request
about: Suggest an idea for this project
title: ''
labels: ''
assignees: ''

---

**Is your feature request related to the way how to work with pyLife, i.e. the API.? If yes, please describe.**
A clear and concise description of what the problem is. Ex. I'm always frustrated when [...]

**Is your feature request about new functionality, new calculation model? If yes please describe**
I would like pyLife to calculate [...] according to the method of [...] as described in [link]

**Describe the solution you'd like**
A clear and concise description of what you want to happen.

**Describe alternatives you've considered**
A clear and concise description of any alternative solutions or features you've considered.

**Indicate if you or someone you know would volunteer to work on this**
It's an open source project, so you are free to contribute stuff.

**Additional context**
Add any other context or screenshots about the feature request here.
